% EmoAtlas documentation master file, created by
% sphinx-quickstart on Tue Nov  8 19:16:58 2022.
% You can adapt this file completely to your liking, but it should at least
% contain the root `toctree` directive.

# Welcome to EmoAtlas's documentation!

```{warning}
The documentation of EmoAtlas is still under development. Feel free to provide feedback at name.surname@unito.it.
```

```{toctree}
:caption: 'Contents:'
:maxdepth: 2

Home <self>
demos/emolib_demo
API_Reference
```

```{include} ../../README.md
:relative-images:
```